@@ -33,8 +33,9 @@ public:
     QString genreUrl() const;
 
     QList<VideoThumbnail> authorThumbnails() const;
+    void setAuthorThumbnails(const QList<VideoThumbnail> &thumbnails);
 
-    QString subCountText() const;
+    qint32 subCount() const;
 
     bool allowRatings() const;
 
@@ -63,7 +64,7 @@ private:
     QString m_genre;
     QString m_genreUrl;
     QList<VideoThumbnail> m_authorThumbnails;
-    QString m_subCountText;
+    qint32 m_subCount = 0;
     double m_rating = 1.0;
     QList<VideoBasicInfo> m_recommendedVideos;
     std::optional<QDateTime> m_premiereTimestamp;
