@@ -3,44 +3,33 @@
 
 #pragma once
 
-#include <QAbstractListModel>
-#include <QDateTime>
+#include "abstractinstancesmodel.h"
+
 #include <QNetworkAccessManager>
-#include <QUrl>
 #include <QtQml>
 
-class PipedInstancesModel : public QAbstractListModel
+class PipedInstancesModel : public AbstractInstancesModel
 {
     Q_OBJECT
     QML_ELEMENT
 
-    Q_PROPERTY(bool loading READ loading NOTIFY loadingChanged)
-
 public:
-    enum CustomRoles { NameRole = Qt::UserRole, URLRole };
-
     explicit PipedInstancesModel(QObject *parent = nullptr);
 
-    bool loading() const;
-    void setLoading(bool loading);
-
     QVariant data(const QModelIndex &index, int role) const override;
     int rowCount(const QModelIndex &parent) const override;
-    QHash<int, QByteArray> roleNames() const override;
 
 Q_SIGNALS:
-    void loadingChanged();
     void filterStringChanged();
 
 private:
     void fill();
 
     struct PipedInstance {
-        QString name, url;
+        QString name, url, regions;
     };
 
     QList<PipedInstance> m_instances;
-    bool m_loading = false;
     QString m_filterString;
     QNetworkAccessManager m_netManager;
 };
